@@ -1,10 +1,13 @@
 from unittest.mock import mock_open, patch
 import pickle
 
+from numpy._typing import NDArray
 import pytest
 import numpy as np
 
 from src.SpectrogramUtils.processors.scaler_audio_processor import ScalerAudioProcessor
+from src.SpectrogramUtils import AbstractDataProcessor
+from src.SpectrogramUtils.exceptions.lib_exceptions import BrokenProcessorException
 
 def test_scaler_data_processor_fit():
     processor = ScalerAudioProcessor()
@@ -38,3 +41,15 @@ def test_scaler_data_processor_loadd():
     with patch("builtins.open", mock_file), patch("pickle.load") as mock_pickle_load:
         processor.load("file.pkl")
         mock_file.assert_called_with("file.pkl", 'rb')
+
+
+def test_broken_processor():
+    class BrokenProcessor(AbstractDataProcessor):
+        def forward(self, data):
+            return data * 2
+        def backward(self, data: NDArray):
+            return data * 2
+    
+    processor = BrokenProcessor()
+    with pytest.raises(BrokenProcessorException):
+        processor._check_reversible()
